@@ -1,5 +1,6 @@
 package Device::Network::ConfigParser;
 # ABSTRACT: A harness for parsing network device configuration.
+our $VERSION = '0.005'; # VERSION
 
 
 use 5.006;
@@ -18,6 +19,92 @@ use Exporter qw{import};
 
 our @EXPORT_OK = qw{app};
 
+=head1 NAME
+
+Device::Network::ConfigParser - harness for parsing network configurations.
+
+=head1 VERSION
+
+version 0.005
+
+=head1 SYNOPSIS
+
+Device::Network::ConfigParser is a harness for parsing network device configuration. It exports a single subroutine - C<app()> - which takes command line arguments and runs the harness. This module is used by the C<ncp> command line utility. For information on how to use the command line utility, refer to the L<ncp>, or following installation type C<perldoc ncp> at the command line.
+
+The harness supports specific parsing modules by:
+
+=over 4
+
+=item * Dynamically loading a specific parsing module based on command line arguments.
+
+=item * Slurping in the device configuration from STDIN or from a number of files.
+
+=item * Opening the required output filehandles.
+
+=back
+
+=head1 CURRENT PARSER MODULES
+
+=over 4
+
+=item L<Device::Network::ConfigParser::Cisco::ASA>
+
+=item L<Device::Network::ConfigParser::CheckPoint::Gaia>
+
+=item L<Device::Network::ConfigParser::CheckPoint::Expert>
+
+=back
+
+=head1 DEVELOPING MODULES
+
+Parsing modules exist within the C<Device::Network::ConfigParser::> namespace. For a I<vendor> and I<type> of device, the module is defined as C<Device::Network::ConfigParser::vendor::type>.
+
+The harness takes care of parsing the command line arguments, opening files (or STDIN/STDOUT) and slurping in their contents. It calls specified subroutines exported by the specified parsing module. All modules must export the following subroutines:
+
+=head2 get_parser
+
+    my $module_parser = get_parser();
+
+This sub receives no arguments, and must return a reference to an object or subroutine that parses the configuration. This is most likely going to be a Parse::RecDescent object, but you're not limited to this.
+
+=head2 parse_config
+
+    my $parsed_config = parse_config($module_parser, $device_config);
+
+This sub receives the reference returned by the C<get_parser> sub, and the full contents of a file specified on the command line. It should return a reference a data structure that represents the parsed configuration.
+
+=head2 post_process
+
+    my $processed_config = post_process($parsed_config);
+
+This sub receives the reference to the data structure returned by C<parse_config>. It allows for some post-processing of the data structure. If no processing is required, it can be defined as C<sub post_process { return @_; }>.
+
+=head2 get_output_drivers
+
+    open($fh, ">>:encoding(UTF-8)", $output_filename);
+    my $output_drivers = get_output_drivers();
+
+    $output_drivers->{csv}->($fh, $output_filename, $processed_config);
+
+This sub takes no arguments, and must return a HASHREF of subroutines used to output the parsed configurationm keyed on the command line argument. For example the sub may return:
+
+    {
+        csv => \&csv_output_driver,
+    }  
+
+The drivers themselves take a filehandle to write the output to (this may be STDOUT), the output filename, and the post-processed configuration.
+
+The driver called is based on the C<--output csv> as a command line argument
+
+There is a default 'raw' driver, which uses Data::Dumper to serialise the structure. A module may return its own 'raw' driver which will override this default.
+
+=head1 SUBROUTINES
+
+=head2 app 
+
+The C<app> subroutine in general takes C<@ARGV> (although it could be any list) and runs the harness.
+
+=cut
 
 sub app {
     local @ARGV = @_;
@@ -103,79 +190,6 @@ sub _default_raw_output_driver {
     print $fh Dumper($parsed_config);
 }
 
-
-1; # End of Device::Network::ConfigParser
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Device::Network::ConfigParser - A harness for parsing network device configuration.
-
-=head1 VERSION
-
-version 0.004
-
-=head1 SYNOPSIS
-
-Device::Network::ConfigParser is a harness for parsing network device configuration. It exports a single subroutine - C<app()> - which takes command line arguments and runs the harness. This module is used by the C<ncp> command line utility. For information on how to use the command line utility, refer to the L<ncp>, or following installation type C<perldoc ncp> at the command line.
-
-The harness supports specific parsing modules by:
-
-=over 4
-
-=item * Dynamically loading a specific parsing module based on command line arguments.
-
-=item * Slurping in the device configuration from STDIN or from a number of files.
-
-=item * Opening the required output filehandles.
-
-=back
-
-=head1 DEVELOPING MODULES
-
-Parsing modules exist within the C<Device::Network::ConfigParser::> namespace. For a I<vendor> and I<type> of device, the module is defined as C<Device::Network::ConfigParser::vendor::type>.
-
-The harness takes care of parsing the command line arguments, opening files (or STDIN/STDOUT) and slurping in their contents. It calls specified subroutines exported by the specified parsing module. Any module must export the following subroutines:
-
-=over 4
-
-=item * B<get_parser>
-
-This sub receives no arguments, and must return a reference to an object or another subroutine that parses the configuration. This is most likely going to be a Parse::RecDescent object, but you're not limited to this.
-
-=item * B<parse_config>
-
-This sub receives the reference returned by the C<get_parser> sub, and the full contents of a file specified on the command line. It should return a reference a data structure that represents the parsed configuration.
-
-=item * B<post_process>
-
-This sub receives the reference to the data structure returned by C<parse_config>. It allows for some post-processing of the data structure. If no processing is required, it can be defined as C<sub post_process { return @_; }>.
-
-=item * B<get_output_drivers>
-
-This sub receives no arguments, and must return a HASHREF of subroutines used to output the parsed configurationm keyed on the command line argument. For example the sub may return:
-
-    {
-        csv => \&csv_output_driver,
-    }  
-
-If the user specified C<--output csv> as a command line argument, the C<csv_output_driver> would be called. When called, each output driver receives a filehandle to write the output to, the name of the file, and the post-processed data structure.
-
-There is a default 'raw' driver always present, which uses Data::Dumper to serialise the structure. The module may return its own 'raw' driver which will override this default.
-
-=back
-
-=head1 SUBROUTINES
-
-=head2 app 
-
-The C<app> subroutine in general takes C<@ARGV> (although it could be any list) and runs the harness.
-
 =head1 AUTHOR
 
 Greg Foletta, C<< <greg at foletta.org> >>
@@ -186,12 +200,16 @@ Please report any bugs or feature requests to C<bug-device-network-configparser
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Device-Network-ConfigParser>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+
+
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Device::Network::ConfigParser
 
+
 You can also look for information at:
 
 =over 4
@@ -214,8 +232,10 @@ L<http://search.cpan.org/dist/Device-Network-ConfigParser/>
 
 =back
 
+
 =head1 ACKNOWLEDGEMENTS
 
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2017 Greg Foletta.
@@ -226,15 +246,7 @@ by the Free Software Foundation; or the Artistic License.
 
 See L<http://dev.perl.org/licenses/> for more information.
 
-=head1 AUTHOR
-
-Greg Foletta <greg@foletta.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2017 by Greg Foletta.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+1; # End of Device::Network::ConfigParser
